http_response_found

Function http_response_found 

pub fn http_response_found(
    location: String,
) -> Result<HttpResponseFound, HttpError>
http_response_found returns an HTTP 302 “Found” response with no response body.

The sole argument will become the value of the Location header. This is where you want to redirect the client to.

Per MDN and RFC 9110 S15.4.3, you might want to use 307 (“Temporary Redirect”) or 303 (“See Other”) instead.